==> vtigercrm-5.3.0p0.tgz: modules/Accounts/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Accounts/language/en_us.lang.php,v 1.18 2005/03/19 08:59:20 rank Exp $
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Contas',
'LBL_MODULE_TITLE'=>'Contas: Home',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar Contas',
'LBL_LIST_FORM_TITLE'=>'Listar Contas',
'LBL_NEW_FORM_TITLE'=>'Nova Conta',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizações Membro',
// Label for Top Accounts in Home Page, added for 4.2 GA
'LBL_TOP_ACCOUNTS'=>'Minhas Principais Contas',
'LBL_TOP_AMOUNT'=>'Quantidade',
'LBL_LIST_ACCOUNT_NAME'=>'Nome Conta',
'LBL_LIST_CITY'=>'Cidade',
'LBL_LIST_WEBSITE'=>'Website',
'LBL_LIST_STATE'=>'Estado',
'LBL_LIST_PHONE'=>'Telefone',
'LBL_LIST_EMAIL_ADDRESS'=>'Endereço Email',
'LBL_LIST_CONTACT_NAME'=>'Nome Contato',
'LBL_LIST_AMOUNT' => 'Total',
      
//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT
      
'LBL_ACCOUNT'=>'Conta:',
'LBL_ACCOUNT_NAME'=>'Nome Conta:',
'LBL_PHONE'=>'Telefone:',
'LBL_WEBSITE'=>'Website:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Cód. Bolsa:',
'LBL_OTHER_PHONE'=>'Telefone Alternativo:',
'LBL_ANY_PHONE'=>'Outro Telefone:',
'LBL_MEMBER_OF'=>'Membro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empregados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email Alterntivo:',
'LBL_ANY_EMAIL'=>'Outro Email:',
'LBL_OWNERSHIP'=>'Proprietário:',
'LBL_RATING'=>'Avaliação:',
'LBL_INDUSTRY'=>'Atividade:',
'LBL_SIC_CODE'=>'Cod CNAE:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Receita Anual:',
'LBL_ADDRESS_INFORMATION'=>'Informação Endereço',
'LBL_ACCOUNT_INFORMATION'=>'Informação Conta',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_BILLING_ADDRESS'=>'Endereço Faturamento:',
'LBL_SHIPPING_ADDRESS'=>'Endereço Entrega:',
'LBL_ANY_ADDRESS'=>'Endereço Alternativo:',
'LBL_CITY'=>'Cidade:',
'LBL_STATE'=>'Estado:',
'LBL_POSTAL_CODE'=>'CEP:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',
'LBL_DESCRIPTION'=>'Descrição:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Endereço Faturamento',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Endereço Entrega',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'Você tem certeza que deseja remover este registro enquanto um membro da organização?',
'LBL_DUPLICATE'=>'Contas com Possibilidade de Duplicação',
'MSG_DUPLICATE' => 'Criando esta vtiger_account poderá criar uma vtiger_potentialy conta duplicada. Você pode também selecionar uma vtiger_account da lista abaixo ou clicar sobre Criar Nova Conta para continuar criando uma nova vtiger_account com os dados anteriores.',

'LBL_INVITEE'=>'Contatos',
'ERR_DELETE_RECORD'=>"Defina um registro para apagar vtiger_account.",

'LBL_SELECT_ACCOUNT'=>'Selecionar Conta',
'LBL_GENERAL_INFORMATION'=>'Informação Geral',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nova Tarefa',
'LBL_TASK_TITLE'=>'Tarefas',
'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',
'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reuniões',
'LBL_NEW_EMAIL'=>'Novo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todos',
'LBL_PROSPECT'=>'Prospect',
'LBL_INVESTOR'=>'Investidor',
'LBL_RESELLER'=>'Revendedor',
'LBL_PARTNER'=>'Parceiro',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas da Conta',
//Added for 4GA
'Account Name'=>'Nome Conta',
'Phone'=>'Telefone',
'Website'=>'Website',
'Fax'=>'Fax',
'Ticker Symbol'=>'Cod. Bolsa',
'Other Phone'=>'Telefone Alternativo',
'Member Of'=>'Membro de',
'Email'=>'Email',
'Employees'=>'Empregados',
'Other Email'=>'Email Alternativo',
'Ownership'=>'Propriedade',
'Rating'=>'Avaliação',
'industry'=>'Atividade',
'SIC Code'=>'Cod CNAE',
'Type'=>'Tipo',
'Annual Revenue'=>'Receita Anual',
'Assigned To'=>'Responsável',
'Billing Address'=>'Endereço Faturamento',
'Shipping Address'=>'Endereço Entrega',
'Billing City'=>'Cidade Faturamento',
'Shipping City'=>'Cidade Entrega',
'Billing State'=>'Estado Faturamento',
'Shipping State'=>'Estado Entrega',
'Billing Code'=>'CEP Faturamento',
'Shipping Code'=>'CEP Entrega',
'Billing Country'=>'País Faturamento',
'Shipping Country'=>'País Entrega',
'Created Time'=>'Hora Criação',
'Modified Time'=>'Hora Modificação',
'Description'=>'Descrição',
'Shipping Po Box'=>'Cx Postal Entrega',
'Billing Po Box'=>'Cx Postal Faturamento',

//Added after 4.2 patch 2
'Email Opt Out'=>'Rejeita Email',
'LBL_EMAIL_OPT_OUT'=>'Rejeita Email:',

//Added after 5Alpha5
'Notify Owner'=>'Notificar Proprietário',

//Added for existing picklist entries
      
'--None--'=>'--Nada--',
      
'Acquired'=>'Aquirido',
'Active'=>'Ativo',
'Market Failed'=>'Venda não realizada',
'Project Cancelled'=>'Projeto Cancelado',
'Shutdown'=>'Encerrado',
      
'Apparel'=>'Vestuário',
'Banking'=>'Bancos',
'Biotechnology'=>'Biotecnologia',
'Chemicals'=>'Química',
'Communications'=>'Comunicações',
'Construction'=>'Construção',
'Consulting'=>'Consultoria',
'Education'=>'Educação',
'Electronics'=>'Eletrônica',
'Energy'=>'Energia',
'Engineering'=>'Engenharia',
'Entertainment'=>'Entretenimento',
'Environmental'=>'Meio Ambiente',
'Finance'=>'Finanças',
'Food & Beverage'=>'Alimentos & Bebidas',
'Government'=>'Governo',
'Healthcare'=>'Saúde',
'Hospitality'=>'Hotéis',
'Insurance'=>'Seguros',
'Machinery'=>'Máquinas',
'Manufacturing'=>'Indústria',
'Media'=>'Mídia',
'Not For Profit'=>'ONG',
'Recreation'=>'Recreação',
'Retail'=>'Comércio',
'Shipping'=>'Transporte Marítimo',
'Technology'=>'Tecnologia',
'Telecommunications'=>'Telecomunicações',
'Transportation'=>'Transportes',
'Utilities'=>'Serviço Público',
'Other'=>'Outro',
      
'Analyst'=>'Analista',
'Competitor'=>'Concorrente',
'Customer'=>'Cliente',
'Integrator'=>'Integrador',
'Investor'=>'Investidor',
'Partner'=>'Parceiro',
'Press'=>'Imprensa',
'Prospect'=>'Prospect',
'Reseller'=>'Revendedor',
'LBL_START_DATE' => 'Data Inicial',
'LBL_END_DATE' => 'Data Final',

// Added/Updated for vtiger CRM 5.0.4

//added to fix the issue #4081
'LBL_ACCOUNT_EXIST' => 'O Nome da Conta já Existe!',

// mailer export
'LBL_MAILER_EXPORT' => 'Exportar',
'LBL_MAILER_EXPORT_CONTACTS_TYPE'=>'Selecione Contatos:',
'LBL_MAILER_EXPORT_CONTACTS_DESCR'=>'Os Contatos também podem ser selecionados a partir dos "Campos Customizados" e através de qualquer campo padrão.',
'LBL_MAILER_EXPORT_RESULTS_TYPE'=>'Selecione o tipo de Exportação:',
'LBL_MAILER_EXPORT_RESULTS_DESCR'=>'Os dados serão obtidos a partir das Contas e seus Contatos, que retornarem
 a partir da pesquisa realizada.',
'LBL_EXPORT_RESULTS_EMAIL' => 'Exportar Contato e E-mail',
'LBL_EXPORT_RESULTS_EMAIL_CORP'=>'Exportar Contatos e E-mails, utilizando o "E-mail da Empresa" se o "E-mail" do Contato estiver vazio',
'LBL_EXPORT_RESULTS_FULL'=>'Exportar dados com Contatos, E-mail, Conta, Endereço, Telefone, etc.',
'LBL_EXPORT_RESULTS_GO'=>'Executar Exportação',
'LBL_MAILER_EXPORT_IGNORE' => '--ignorar--',
'LBL_MAILER_EXPORT_CHECKED' =>'Checado',
'LBL_MAILER_EXPORT_NOTCHECKED' => 'Não Checado',

// Added after 5.0.4 GA

//Module Sequence Numbering
'Account No'=>'Cód. Conta',
// END

// Account Hierarchy
'LBL_SHOW_ACCOUNT_HIERARCHY' => 'Mostrar Hierarquia da Conta',

);

?>

==> vtigercrm-5.4.0.tgz: modules/Accounts/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Accounts/language/en_us.lang.php,v 1.18 2005/03/19 08:59:20 rank Exp $
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Organizações',
'LBL_MODULE_TITLE'=>'Organizações: Home',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar Organizações',
'LBL_LIST_FORM_TITLE'=>'Listar Organizações',
'LBL_NEW_FORM_TITLE'=>'Nova Organização',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizações Membro',
// Label for Top Accounts in Home Page, added for 4.2 GA
'LBL_TOP_ACCOUNTS'=>'Minhas Principais Organizações',
'LBL_TOP_AMOUNT'=>'Quantidade',
'LBL_LIST_ACCOUNT_NAME'=>'Nome Organização',
'LBL_LIST_CITY'=>'Cidade',
'LBL_LIST_WEBSITE'=>'Website',
'LBL_LIST_STATE'=>'Estado',
'LBL_LIST_PHONE'=>'Telefone',
'LBL_LIST_EMAIL_ADDRESS'=>'Endereço Email',
'LBL_LIST_CONTACT_NAME'=>'Nome Contato',
'LBL_LIST_AMOUNT' => 'Total',
      
//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',

//END DON'T CONVERT
      
'LBL_ACCOUNT'=>'Organização:',
'LBL_ACCOUNT_NAME'=>'Nome Organização:',
'LBL_PHONE'=>'Telefone:',
'LBL_WEBSITE'=>'Website:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Cód. Bolsa:',
'LBL_OTHER_PHONE'=>'Telefone Alternativo:',
'LBL_ANY_PHONE'=>'Outro Telefone:',
'LBL_MEMBER_OF'=>'Membro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empregados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email Alterntivo:',
'LBL_ANY_EMAIL'=>'Outro Email:',
'LBL_OWNERSHIP'=>'Proprietário:',
'LBL_RATING'=>'Avaliação:',
'LBL_INDUSTRY'=>'Atividade:',
'LBL_SIC_CODE'=>'Cod CNAE:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Receita Anual:',
'LBL_ADDRESS_INFORMATION'=>'Informação Endereço',
'LBL_ACCOUNT_INFORMATION'=>'Informação Organização',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',
'LBL_BILLING_ADDRESS'=>'Endereço Faturamento:',
'LBL_SHIPPING_ADDRESS'=>'Endereço Entrega:',
'LBL_ANY_ADDRESS'=>'Endereço Alternativo:',
'LBL_CITY'=>'Cidade:',
'LBL_STATE'=>'Estado:',
'LBL_POSTAL_CODE'=>'CEP:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',
'LBL_DESCRIPTION'=>'Descrição:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar Endereço Faturamento',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar Endereço Entrega',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'Você tem certeza que deseja remover este registro enquanto um membro da organização?',
'LBL_DUPLICATE'=>'Organizações com Possibilidade de Duplicação',
'MSG_DUPLICATE' => 'Criando esta vtiger_account poderá criar uma vtiger_potentialy Organização duplicada. Você pode também selecionar uma vtiger_account da lista abaixo ou clicar sobre Criar Nova Organização para continuar criando uma nova vtiger_account com os dados anteriores.',

'LBL_INVITEE'=>'Contatos',
'ERR_DELETE_RECORD'=>"Defina um registro para apagar vtiger_account.",

'LBL_SELECT_ACCOUNT'=>'Selecionar Organização',
'LBL_GENERAL_INFORMATION'=>'Informação Geral',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nova Tarefa',
'LBL_TASK_TITLE'=>'Tarefas',
'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',
'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reuniões',
'LBL_NEW_EMAIL'=>'Novo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todos',
'LBL_PROSPECT'=>'Prospect',
'LBL_INVESTOR'=>'Investidor',
'LBL_RESELLER'=>'Revendedor',
'LBL_PARTNER'=>'Parceiro',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas da Organização',
//Added for 4GA
'Account Name'=>'Nome Organização',
'Phone'=>'Telefone',
'Website'=>'Website',
'Fax'=>'Fax',
'Ticker Symbol'=>'Cod. Bolsa',
'Other Phone'=>'Telefone Alternativo',
'Member Of'=>'Membro de',
'Email'=>'Email',
'Employees'=>'Empregados',
'Other Email'=>'Email Alternativo',
'Ownership'=>'Propriedade',
'Rating'=>'Avaliação',
'industry'=>'Atividade',
'SIC Code'=>'Cod CNAE',
'Type'=>'Tipo',
'Annual Revenue'=>'Receita Anual',
'Assigned To'=>'Responsável',
'Billing Address'=>'Endereço Faturamento',
'Shipping Address'=>'Endereço Entrega',
'Billing City'=>'Cidade Faturamento',
'Shipping City'=>'Cidade Entrega',
'Billing State'=>'Estado Faturamento',
'Shipping State'=>'Estado Entrega',
'Billing Code'=>'CEP Faturamento',
'Shipping Code'=>'CEP Entrega',
'Billing Country'=>'País Faturamento',
'Shipping Country'=>'País Entrega',
'Created Time'=>'Hora Criação',
'Modified Time'=>'Hora Modificação',
'Description'=>'Descrição',
'Shipping Po Box'=>'Cx Postal Entrega',
'Billing Po Box'=>'Cx Postal Faturamento',

//Added after 4.2 patch 2
'Email Opt Out'=>'Rejeita Email',
'LBL_EMAIL_OPT_OUT'=>'Rejeita Email:',

//Added after 5Alpha5
'Notify Owner'=>'Notificar Proprietário',

//Added for existing picklist entries
      
'--None--'=>'--Nada--',
      
'Acquired'=>'Aquirido',
'Active'=>'Ativo',
'Market Failed'=>'Venda não realizada',
'Project Cancelled'=>'Projeto Cancelado',
'Shutdown'=>'Encerrado',
      
'Apparel'=>'Vestuário',
'Banking'=>'Bancos',
'Biotechnology'=>'Biotecnologia',
'Chemicals'=>'Química',
'Communications'=>'Comunicações',
'Construction'=>'Construção',
'Consulting'=>'Consultoria',
'Education'=>'Educação',
'Electronics'=>'Eletrônica',
'Energy'=>'Energia',
'Engineering'=>'Engenharia',
'Entertainment'=>'Entretenimento',
'Environmental'=>'Meio Ambiente',
'Finance'=>'Finanças',
'Food & Beverage'=>'Alimentos & Bebidas',
'Government'=>'Governo',
'Healthcare'=>'Saúde',
'Hospitality'=>'Hotéis',
'Insurance'=>'Seguros',
'Machinery'=>'Máquinas',
'Manufacturing'=>'Indústria',
'Media'=>'Mídia',
'Not For Profit'=>'ONG',
'Recreation'=>'Recreação',
'Retail'=>'Comércio',
'Shipping'=>'Transporte Marítimo',
'Technology'=>'Tecnologia',
'Telecommunications'=>'Telecomunicações',
'Transportation'=>'Transportes',
'Utilities'=>'Serviço Público',
'Other'=>'Outro',
      
'Analyst'=>'Analista',
'Competitor'=>'Concorrente',
'Customer'=>'Cliente',
'Integrator'=>'Integrador',
'Investor'=>'Investidor',
'Partner'=>'Parceiro',
'Press'=>'Imprensa',
'Prospect'=>'Prospect',
'Reseller'=>'Revendedor',
'LBL_START_DATE' => 'Data Inicial',
'LBL_END_DATE' => 'Data Final',

// Added/Updated for vtiger CRM 5.0.4

//added to fix the issue #4081
'LBL_ACCOUNT_EXIST' => 'O Nome da Organização já Existe!',

// mailer export
'LBL_MAILER_EXPORT' => 'Exportar',
'LBL_MAILER_EXPORT_CONTACTS_TYPE'=>'Selecione Contatos:',
'LBL_MAILER_EXPORT_CONTACTS_DESCR'=>'Os Contatos também podem ser selecionados a partir dos "Campos Customizados" e através de qualquer campo padrão.',
'LBL_MAILER_EXPORT_RESULTS_TYPE'=>'Selecione o tipo de Exportação:',
'LBL_MAILER_EXPORT_RESULTS_DESCR'=>'Os dados serão obtidos a partir das Organizações e seus Contatos, que retornarem
 a partir da pesquisa realizada.',
'LBL_EXPORT_RESULTS_EMAIL' => 'Exportar Contato e E-mail',
'LBL_EXPORT_RESULTS_EMAIL_CORP'=>'Exportar Contatos e E-mails, utilizando o "E-mail da Empresa" se o "E-mail" do Contato estiver vazio',
'LBL_EXPORT_RESULTS_FULL'=>'Exportar dados com Contatos, E-mail, Organização, Endereço, Telefone, etc.',
'LBL_EXPORT_RESULTS_GO'=>'Executar Exportação',
'LBL_MAILER_EXPORT_IGNORE' => '--ignorar--',
'LBL_MAILER_EXPORT_CHECKED' =>'Checado',
'LBL_MAILER_EXPORT_NOTCHECKED' => 'Não Checado',

// Added after 5.0.4 GA

//Module Sequence Numbering
'Account No'=>'Cód. Organização',
// END

// Organization Hierarchy
'LBL_SHOW_ACCOUNT_HIERARCHY' => 'Mostrar Hierarquia da Organização',
'Accounts ID' => 'ID Organizações',

);

?>
